@@ -874,7 +874,7 @@ def plot_volcano(diffusion_values:pd.Series, test_values:pd.Series, tol_diffusio
         # DEGs
         significant_diffusion = x.abs() >= tol_diffusion
         significant_test = y < tol_test
-        idx_degs = (significant_diffusion.astype(int) + significant_test.astype(int)).compress(lambda z: z == 2).index
+        idx_degs = (significant_diffusion.astype(int) + significant_test.astype(int))[lambda z: z == 2].index
         vmax = x[idx_degs].abs().max()
 
         # Plot data
